# Fedora repo spec file for php-pecl-libsodium
# with SCL compatibility removed, from
#
# remirepo spec file for php-pecl-libsodium
#
# Copyright (c) 2014-2016 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global with_zts   0%{?__ztsphp:1}
%global pecl_name  libsodium
%global with_tests 0%{!?_without_tests:1}
%global ini_name   40-%{pecl_name}.ini
%global buildver   %(pkg-config --silence-errors --modversion libsodium 2>/dev/null || echo 65536)

Summary:        Wrapper for the Sodium cryptographic library
Name:           php-pecl-%{pecl_name}
Version:        1.0.6
Release:        6%{?dist}
License:        BSD
Group:          Development/Languages
URL:            http://pecl.php.net/package/%{pecl_name}
Source0:        http://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  libsodium-devel >= 0.6.0
BuildRequires:  php-devel > 5.4
BuildRequires:  php-pear
BuildRequires:  php-json
BuildRequires:  pkgconfig

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       libsodium%{?_isa} >= %{buildver}

Provides:       php-%{pecl_name} = %{version}
Provides:       php-%{pecl_name}%{?_isa} = %{version}
Provides:       php-pecl(%{pecl_name}) = %{version}
Provides:       php-pecl(%{pecl_name})%{?_isa} = %{version}

# Filter shared private - always as libsodium.so is a bad name
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}


%description
A simple, low-level PHP extension for libsodium.

Documentation: https://paragonie.com/book/pecl-libsodium


%prep
%setup -q -c
mv %{pecl_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd NTS

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_LIBSODIUM_VERSION/{s/.* "//;s/".*$//;p}' php_libsodium.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=json.so -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/zts-php \
TEST_PHP_ARGS="-n -d extension=json.so -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{_bindir}/zts-php -n run-tests.php --show-diff
%endif
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%license NTS/LICENSE
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 07 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.0.6-4
- Rebuild due to bug in RPM (RHBZ #1468476)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Nov 14 2016 Remi Collet <remi@fedoraproject.org> - 1.0.6-2
- rebuild for https://fedoraproject.org/wiki/Changes/php71

* Mon Jun 27 2016 Remi Collet <remi@fedoraproject.org> - 1.0.6-1
- Update to 1.0.6

* Fri Apr 08 2016 Remi Collet <remi@fedoraproject.org> - 1.0.5-1
- Update to 1.0.5

* Tue Apr  5 2016 Remi Collet <remi@fedoraproject.org> - 1.0.4-1
- update to 1.0.4

* Mon Mar 07 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-4
- rebuild for new libsodium soname

* Wed Feb 10 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-3
- drop scriptlets (replaced by file triggers in php-pear)
- cleanup

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 30 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- cleanup for fedora review

* Wed Nov  4 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-2
- rebuild against libsodium 1.0.6

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2
- drop all patches, merged upstream

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1
- fix for old libsodium
  https://github.com/jedisct1/libsodium-php/pull/63
- don't zero interned string
  https://github.com/jedisct1/libsodium-php/pull/62
- add dependency on libsodium version used at build time

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-3
- rebuild for PHP 7.0.0RC5 new API version

* Fri Sep 18 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-2
- F23 rebuild with rh_layout

* Thu Sep 03 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- Update to 1.0.0 (stable)

* Mon Jul 27 2015 Remi Collet <remi@fedoraproject.org> - 0.2.1-1
- Update to 0.2.1 (beta)

* Sun Jul 26 2015 Remi Collet <remi@fedoraproject.org> - 0.2.0-1
- Update to 0.2.0 (beta)

* Wed Jul 22 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-4
- rebuild against php 7.0.0beta2

* Wed Jul  8 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-3
- rebuild against php 7.0.0beta1

* Wed Jun 24 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-2
- allow build against rh-php56 (as more-php56)
- rebuild for "rh_layout" (php70)

* Wed Apr 15 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-1
- Update to 0.1.3 (beta)

* Thu Apr 02 2015 Remi Collet <remi@fedoraproject.org> - 0.1.2-1
- Update to 0.1.2 (beta)
- drop runtime dependency on pear, new scriptlets
- open https://github.com/jedisct1/libsodium-php/pull/22 - build
- open https://github.com/jedisct1/libsodium-php/pull/23 - php 7

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-1.1
- Fedora 21 SCL mass rebuild

* Sun Sep 28 2014 Remi Collet <rcollet@redhat.com> - 0.1.1-1
- initial package, version 0.1.1 (beta)
- open https://github.com/jedisct1/libsodium-php/pull/14
